@@ -89,9 +89,16 @@ fn bincode() {
 #[cfg(feature = "codec-cbor")]
 #[test]
 fn cbor() {
+    #[allow(deprecated)]
     roundtrip::<TestStruct, codec::Cbor>()
 }
 
+#[cfg(feature = "codec-ciborium")]
+#[test]
+fn ciborium() {
+    roundtrip::<TestStruct, codec::Ciborium>()
+}
+
 #[cfg(feature = "codec-json")]
 #[test]
 #[should_panic]
