@@ -59,6 +59,16 @@ where
     loop_channel_with_cfg(cfg).await
 }
 
+#[cfg(feature = "rch")]
+pub async fn droppable_loop_channel<T>(
+) -> ((base::Sender<T>, base::Receiver<T>), (base::Sender<T>, base::Receiver<T>), tokio::sync::mpsc::Receiver<()>)
+where
+    T: RemoteSend,
+{
+    let cfg = remoc::chmux::Cfg::default();
+    droppable_loop_channel_with_cfg(cfg).await
+}
+
 #[cfg(feature = "rch")]
 pub async fn loop_channel_with_cfg<T>(
     cfg: remoc::chmux::Cfg,
@@ -66,23 +76,50 @@ pub async fn loop_channel_with_cfg<T>(
 where
     T: RemoteSend,
 {
+    let (a, b, mut drop_rx) = droppable_loop_channel_with_cfg(cfg).await;
+    tokio::spawn(async move {
+        let _ = drop_rx.recv().await;
+    });
+    (a, b)
+}
+
+#[cfg(feature = "rch")]
+pub async fn droppable_loop_channel_with_cfg<T>(
+    cfg: remoc::chmux::Cfg,
+) -> ((base::Sender<T>, base::Receiver<T>), (base::Sender<T>, base::Receiver<T>), tokio::sync::mpsc::Receiver<()>)
+where
+    T: RemoteSend,
+{
+    let (drop_tx, drop_rx) = tokio::sync::mpsc::channel(1);
     loop_transport!(0, transport_a_tx, transport_a_rx, transport_b_tx, transport_b_rx);
 
     let a_cfg = cfg.clone();
+    let a_drop_tx = drop_tx.clone();
     let a = async move {
         let (conn, tx, rx) = remoc::Connect::framed(a_cfg, transport_a_tx, transport_a_rx).await.unwrap();
-        tokio::spawn(conn);
+        tokio::spawn(async move {
+            tokio::select! {
+                _ = conn => (),
+                _ = a_drop_tx.closed() => (),
+            }
+        });
         (tx, rx)
     };
 
     let b_cfg = cfg.clone();
     let b = async move {
         let (conn, tx, rx) = remoc::Connect::framed(b_cfg, transport_b_tx, transport_b_rx).await.unwrap();
-        tokio::spawn(conn);
+        tokio::spawn(async move {
+            tokio::select! {
+                _ = conn => (),
+                _ = drop_tx.closed() => (),
+            }
+        });
         (tx, rx)
     };
 
-    join!(a, b)
+    let (a, b) = join!(a, b);
+    (a, b, drop_rx)
 }
 
 #[cfg(feature = "rch")]
